'use strict';

var fs = require('fs');
var path = require('path');
var rollupPluginutils = require('rollup-pluginutils');

var defaults = {
  dom: false,
  exclude: null,
  include: null
};

var mimeTypes = {
  '.jpg': 'image/jpeg',
  '.jpeg': 'image/jpeg',
  '.png': 'image/png',
  '.gif': 'image/gif',
  '.svg': 'image/svg+xml',
  '.webp': 'image/webp'
};

function image(opts) {
  if ( opts === void 0 ) opts = {};

  var options = Object.assign({}, defaults, opts);
  var filter = rollupPluginutils.createFilter(options.include, options.exclude);

  return {
    name: 'image',

    load: function load(id) {
      if (!filter(id)) {
        return null;
      }

      var mime = mimeTypes[path.extname(id)];
      if (!mime) {
        // not an image
        return null;
      }

      var source = fs.readFileSync(id, 'base64');
      var data = "'data:" + mime + ";base64," + source + "'";
      var code = options.dom
        ? ("var img = new Image(); img.src = " + data + "; export default img;")
        : ("const img = " + data + "; export default img;");

      return code;
    }
  };
}

module.exports = image;
//# sourceMappingURL=index.js.map
